function OscRecordFlt=oscdenoise(OscRecord,wfms=[],windowLength=0.005)
  
# OscRecordFlt = oscdenoise(OscRecord, idx, windowLength)
#
# Denoises waveforms specified by wfms as contained in the structure OscRecord 
# by applying a linear-weighted running average filter and returns a 
# corresponding structure with the specified waveforms denoised. Unaffected 
# waveforms are directly copied from OscRecord to OscRecordFlt.
#
# The optional parameter wfms is a vector that specifies waveforms on which 
# denoising is to be performed. If it is not provided or is empty, all the 
# waveforms contained in OscRecord are processed. If wfms is a vector of numbers, 
# then they are treated as indices of the respective waveforms within OscRecord.
# Otherwise, it should be a vertical vector of strings, which are treated as 
# waveform labels as set in the oscilloscope.
#
# The optional parameter windowLength, defaulting to 0.005, specifies the 
# running average window length in samples as a fraction of the total number 
# of samples in a given waveform.

# Author:
#   Lukasz Starzak 
#   Dept. of Microelectronics and Computer Science, Lodz University of Technology

  if (isempty(wfms))
    wfms = [1:OscRecord.nWfms];
  elseif (!isnumeric(wfms))
    wfmLabels = wfms;
    wfms = [];
    for iWfm = [1:size(wfmLabels,1)]
      wfms = [wfms oscwfmidx(OscRecord, wfmLabels(iWfm,:))];
    endfor
  endif
  
  OscRecordFlt = OscRecord;
  
  for iWfm = wfms
    OscRecordFlt.Waveforms(iWfm).Values.y = ...
      wavglinn(OscRecord.Waveforms(iWfm).Values.y, ...
      round(OscRecord.Waveforms(iWfm).Params.length * windowLength));
  endfor

endfunction
