function [integral,x1,x2]=oscintegral3rel(OscRecord, wfmInt, wfm1, yrel1, wfm2, yrel2, isZeroBase=true, shouldPlot=false)

# [integral, x1, x2] = oscintegral3rel(OscRecord, ...
# wfmInt, wfm1, yrel1, wfm2, yrel2, isZeroBase, shouldPlot)
#
# Calculates the integral of the waveform wfmInt over its x-axis (as contained 
# in the structure OscRecord) from a point x1 where the waveform wfm1 first 
# crosses the level y1 to a point x2 where the waveform wfm2 subsequently crosses 
# the level y2.
#
# The levels y1 and y2 are specified relative to the magnitudes of wfm1 and 
# wfm2, respectively, as yrel1 and yrel2. For a description of how yrel1 and 
# yrel2 are converted to y1 and y2, as well as of the meaning of the optional 
# parameter isZeroBase (defaulting to true), see rel2abs().
#
# If the optional parameter shouldPlot is true, then the operation is illustrated 
# in a graph with three sub-plots, with the first one visualises the point 
# (x1, y1) on the waveform wfm1; the second one, the point (x2, y2) on the 
# waveform wfm2; and the third one, the area under the waveform wfmInt 
# corresponding to the integral.
#
# If wfm* is a number, it is treated as the index of the respective waveform 
# within OscRecord. Otherwise, it is treated as its label as set in the 
# oscilloscope.
  
# Author:
#   Lukasz Starzak 
#   Dept. of Microelectronics and Computer Science, Lodz University of Technology

  y1 = rel2abs(OscRecord.Waveforms(wfm1).Values.y, yrel1, isZeroBase);
  y2 = rel2abs(OscRecord.Waveforms(wfm2).Values.y, yrel2, isZeroBase);
  [integral,x1,x2] = oscintegral3(OscRecord, wfmInt, wfm1, y1, wfm2, y2, shouldPlot);
  
endfunction
