function [iSample,xVal]=oscsearchx(Waveform,x)

# [iSample, xVal] = oscsearchx(Waveform, x)
#
# Returns the sample index for Waveform that corresponds to its x-coordinate 
# given. The exact x-value of the sample found, considering the discrete 
# character of the x-axis, is also returned as xVal.
#
# Waveform is a structure containing waveform data which is a field of an 
# OscRecord structure. For a description of OscRecord, see oscreadtbs().
#
# If all the samples have their x-values lower than x, iSample = -1 and xVal 
# corresponds to the last sample in Waveform.
  
# Author:
#   Lukasz Starzak 
#   Dept. of Microelectronics and Computer Science, Lodz University of Technology

  xVals = Waveform.Values.x;
  nSamples = Waveform.Params.length;
  iSample = 1;
  while ((iSample <= nSamples) && (xVals(iSample) < x))
    iSample++;
  endwhile
  if (iSample <= nSamples)
    if (iSample > 1 && abs(xVals(iSample-1)-x) < abs(xVals(iSample)-x))
      iSample--;
    endif
    xVal = xVals(iSample);
  else
    iSample = -1;
    xVal = xVals(nSamples);
  endif
  
endfunction
