function [y,xVal]=oscyatx(OscRecord,wfm,x)

# [y, xVal] = oscyatx(OscRecord, wfm, x)
#
# Returns the y-value of the waveform wfm (as contained in the structure 
# OscRecord), corresponding to the given x-coordinate. The exact x-value 
# corresponding to y, considering the discrete character of the x-axis, is also 
# returned as xVal.
# 
# If wfm is a number, it is treated as the index of the waveform within 
# OscRecord. Otherwise, it is treated as its label as set in the oscilloscope.
  
# Author:
#   Lukasz Starzak 
#   Dept. of Microelectronics and Computer Science, Lodz University of Technology

  if (!isnumeric(wfm))
    wfm = oscwfmidx(OscRecord, wfm);
  endif
  
  Waveform = OscRecord.Waveforms(wfm);
  iSample = oscsearchx(Waveform, x);
  y = Waveform.Values.y(iSample);
  xVal = Waveform.Values.x(iSample);
  
endfunction
