function [yStat,iLength]=stationaryvalue(y,isFinal=true,shouldPlot=false)

# [yStat,iLength] = stationaryvalue(y, isFinal)
#
# Returns the stationary level of y. If isFinal is true (default), then the 
# final portion of y is considered the stationary state; otherwise, its initial 
# portion is. The length of the portion (in samples) where a stationary state has 
# been detected is additionally returned as iLength.
#
# If the optional parameter shouldPlot is true, then the result is illustrated 
# in a graph.
  
# Author:
#   Lukasz Starzak 
#   Dept. of Microelectronics and Computer Science, Lodz University of Technology

  PRELIMINARY_THR = 0.05;
  MEAN_RANGE_STD = 1.5;
  
  if (isFinal)
    y = flip(y);
  endif
  
  thr = PRELIMINARY_THR*range(y);
  nSamples = numel(y);
  iSample = 2;
  while ((abs(y(iSample)-y(1)) <= thr) && (iSample <= nSamples))
    iSample++;
  endwhile
  yStd = std(y(1:iSample-1));
  
  iSample = 2;
  while (abs(y(iSample)-y(1)) <= MEAN_RANGE_STD*yStd)
    iSample++;
  endwhile
  iLength = iSample-1;
  yStat = mean(y(1:iLength));
  
  if (shouldPlot)
    figure();
    hold on;
    if (!isFinal)
      plot([1:nSamples], y);
      plot([1 iLength], [yStat yStat], ":r");
    else
      plot([1:nSamples], flip(y));
      plot([nSamples-iLength+1 nSamples], [yStat yStat], ":r");
    end
  endif
  
endfunction
